@@ -1,20 +1,28 @@
 #!/bin/bash
 
-DISTRO="unstable" # TODO lister les valeurs possibles (debian ? ubuntu ? elementary ?)
-PACKAGE_NAME="drawing" # TODO et pour elementary ?
-VERSION="0.4.10"
+DISTRO="unstable" # this script is for local use, distros manage this themselves
+PACKAGE_NAME="drawing" # XXX ask it as an input maybe?
+VERSION="0.6.4"
+
+function separator () {
+	echo ""
+	echo "---------------------------------------------------------------------"
+	echo ""
+}
 
 echo "targeted distribution: $DISTRO"
 echo "package name: $PACKAGE_NAME"
 echo "package version: $VERSION"
 echo ""
-echo "Is it correct? [Return/^C]" # XXX ptêt écrasé dans la suite des opérations ?
+echo "Is it correct? [Return/^C]"
 read confirmation
+separator
 
-# se souvenir du dossier courant (qui est la racine du projet) pour y amener le paquet à la fin
+# remember current directory (theorically, the project's root) to bring the
+# package here in the end
 previous_dir=`pwd`
 
-# mettre en place la structure à la con voulue par les scripts de debian
+# set up the stupidly specific structure required by debian scripts
 DIR_NAME=$PACKAGE_NAME'-'$VERSION
 FILE_NAME=$PACKAGE_NAME'_'$VERSION
 DIR_PATH=/tmp/building-dir
@@ -29,17 +37,20 @@ cp meson.build $DIR_PATH/$DIR_NAME/
 cd $DIR_PATH/
 tar -Jcvf $FILE_NAME.orig.tar.xz $DIR_NAME
 cd $DIR_PATH/$DIR_NAME/
+separator
 
-# création automatique des fichiers supplémentaires pour la construction
+# automatic creation of additional files for the build process
 dh_make -i -y
+separator
 
-# la construction
+# actually building the package
 dpkg-buildpackage -i -us -uc -b
+separator
 
-# récupérer le paquet dans /tmp
+# get the package in /tmp and move it where the user is
 cp $DIR_PATH/*.deb $previous_dir
 
-# nettoyage
+# cleaning
 ls $DIR_PATH
 ls $DIR_PATH/$DIR_NAME
 rm -r $DIR_PATH
